@@ -26,15 +26,13 @@ from cliff import command
 from cliff import commandmanager
 from cliff import complete
 from cliff import help
-from keystoneauth1.identity import v2
-from keystoneauth1.identity import v3
+from keystoneauth1 import identity
 from keystoneauth1 import loading
 from keystoneauth1 import session
-import six
 
-from barbicanclient import client
+import barbicanclient
 from barbicanclient._i18n import _LW
-from barbicanclient import version
+from barbicanclient import client
 
 
 LOG = logging.getLogger(__name__)
@@ -60,7 +58,7 @@ class Barbican(app.App):
 
         super(Barbican, self).__init__(
             description=__doc__.strip(),
-            version=version.__version__,
+            version=barbicanclient.__version__,
             command_manager=commandmanager.CommandManager(
                 'openstack.key_manager.v1'),
             deferred_help=True,
@@ -122,7 +120,7 @@ class Barbican(app.App):
             }
 
         # Return a dictionary with only the populated (not None) values
-        return dict((k, v) for (k, v) in six.iteritems(kwargs) if v)
+        return dict((k, v) for (k, v) in kwargs.items() if v)
 
     def create_keystone_session(
             self, args, api_version, kwargs_dict, auth_type
@@ -133,19 +131,17 @@ class Barbican(app.App):
         kwargs = self.build_kwargs_based_on_version(args, api_version)
         kwargs.update(kwargs_dict)
 
-        if api_version in _IDENTITY_API_VERSION_2:
-            method = v2.Token if auth_type == 'token' else v2.Password
-        else:
-            if not api_version or api_version not in _IDENTITY_API_VERSION_3:
-                self.stderr.write(
-                    "WARNING: The identity version <{0}> is not in supported "
-                    "versions <{1}>, falling back to <{2}>.".format(
-                        api_version,
-                        _IDENTITY_API_VERSION_2 + _IDENTITY_API_VERSION_3,
-                        _DEFAULT_IDENTITY_API_VERSION
-                    )
+        _supported_version = _IDENTITY_API_VERSION_2 + _IDENTITY_API_VERSION_3
+        if not api_version or api_version not in _supported_version:
+            self.stderr.write(
+                "WARNING: The identity version <{0}> is not in supported "
+                "versions <{1}>, falling back to <{2}>.".format(
+                    api_version,
+                    _IDENTITY_API_VERSION_2 + _IDENTITY_API_VERSION_3,
+                    _DEFAULT_IDENTITY_API_VERSION
                 )
-            method = v3.Token if auth_type == 'token' else v3.Password
+            )
+        method = identity.Token if auth_type == 'token' else identity.Password
 
         auth = method(**kwargs)
 
@@ -223,6 +219,7 @@ class Barbican(app.App):
 
     def build_option_parser(self, description, version, argparse_kwargs=None):
         """Introduces global arguments for the application.
+
         This is inherited from the framework.
         """
         parser = super(Barbican, self).build_option_parser(
@@ -324,6 +321,7 @@ class Barbican(app.App):
 
     def prepare_to_run_command(self, cmd):
         """Prepares to run the command
+
         Checks if the minimal parameters are provided and creates the
         client interface.
         This is inherited from the framework.
